@@ -20,7 +20,7 @@
 #include "nautilus-places-view.h"
 #include "nautilus-window-slot.h"
 #include "nautilus-application.h"
-#include "gtk/gtkplacesviewprivate.h"
+#include "gtk/nautilusgtkplacesviewprivate.h"
 
 typedef struct
 {
@@ -251,7 +251,7 @@ nautilus_places_view_set_search_query (NautilusView  *view,
 
         text = query ? nautilus_query_get_text (query) : NULL;
 
-        gtk_nautilus_places_view_set_search_query (GTK_NAUTILUS_PLACES_VIEW (priv->places_view), text);
+        nautilus_gtk_places_view_set_search_query (NAUTILUS_GTK_PLACES_VIEW (priv->places_view), text);
 
         g_free (text);
 }
@@ -270,7 +270,7 @@ nautilus_places_view_is_loading (NautilusView *view)
 
         priv = nautilus_places_view_get_instance_private (NAUTILUS_PLACES_VIEW (view));
 
-        return gtk_nautilus_places_view_get_loading (GTK_NAUTILUS_PLACES_VIEW (priv->places_view));
+        return nautilus_gtk_places_view_get_loading (NAUTILUS_GTK_PLACES_VIEW (priv->places_view));
 }
 
 static gboolean
@@ -329,8 +329,8 @@ nautilus_places_view_init (NautilusPlacesView *self)
         priv->location = g_file_new_for_uri ("other-locations:///");
 
         /* Places view */
-        priv->places_view = gtk_nautilus_places_view_new ();
-        gtk_nautilus_places_view_set_open_flags (GTK_NAUTILUS_PLACES_VIEW (priv->places_view),
+        priv->places_view = nautilus_gtk_places_view_new ();
+        nautilus_gtk_places_view_set_open_flags (NAUTILUS_GTK_PLACES_VIEW (priv->places_view),
                                                  GTK_PLACES_OPEN_NEW_TAB | GTK_PLACES_OPEN_NEW_WINDOW | GTK_PLACES_OPEN_NORMAL);
         gtk_widget_set_hexpand (priv->places_view, TRUE);
         gtk_widget_set_vexpand (priv->places_view, TRUE);
